@@ -204,7 +204,12 @@ def check_db():
         con.execute("ALTER TABLE songs ADD COLUMN playcount INT")
 
 def setup_db():
-    os.makedirs(os.path.dirname(db_file))
+    try:
+        os.makedirs(os.path.dirname(db_file))
+    except OSError:
+        # dir already exists
+        pass
+        
     con = sqlite3.connect(db_file)
 
     con.execute("CREATE TABLE songs (uri TEXT, title TEXT, artist TEXT, album TEXT, genre TEXT, tracknumber INT, playcount INT, date TEXT)")
