@@ -1,6 +1,8 @@
 import gtk
 import pango
 
+from youamp.ui.utils import CoverImage
+
 class DetailsWindow(gtk.Window):
     __instance = None
     
@@ -48,8 +50,8 @@ class DetailsWindow(gtk.Window):
         hbox.set_spacing(5)
         vbox.pack_start(hbox)
         
-        self._cover = gtk.Image()
-        self._cover.set_size_request(-1, 300)
+        self._cover = CoverImage()
+        self._cover.set_size_request(300, 300)
         hbox.pack_start(self._cover, expand=False)
         
         dbox = gtk.VBox()
@@ -91,13 +93,7 @@ class DetailsWindow(gtk.Window):
       
         self.set_title(_("Details for %s") % song["title"])
         
-        cover_file = song.cover_uri()
-        
-        if cover_file is not None:
-            pb = gtk.gdk.pixbuf_new_from_file_at_size(cover_file, 300, 300)
-            self._cover.set_from_pixbuf(pb)
-        else:
-            self._cover.set_from_pixbuf(None)
+        self._cover.set_from_song(song)
         
         for k, l in self._data.iteritems():
             l.set_text(str(song[k]))
