@@ -2,19 +2,20 @@ import gtk
 from youamp.ui.detailswindow import DetailsWindow
 
 class PopupMenu(gtk.Menu):
-    def __init__(self, config):
+    def __init__(self, config, player):
         gtk.Menu.__init__(self)
 
-        self._song = None
+        self.song = None
         self._details = DetailsWindow.get_instance()
             
         self._config = config
         
-        #enq = gtk.ImageMenuItem(_("Add to Play Queue"))
-        #enq.set_image(gtk.image_new_from_stock(gtk.STOCK_ADD, gtk.ICON_SIZE_MENU))    
-        #self.append(enq)
+        enq = gtk.ImageMenuItem(_("Play this next"))
+        enq.set_image(gtk.image_new_from_stock(gtk.STOCK_JUMP_TO, gtk.ICON_SIZE_MENU))
+        enq.connect("activate", self._jump_next_to, player)  
+        self.append(enq)
         
-        #self.append(gtk.SeparatorMenuItem())
+        self.append(gtk.SeparatorMenuItem())
         
         bar = gtk.MenuItem(_("View this Artist"))
         bar.connect("activate", self._browse_artist)
@@ -33,8 +34,11 @@ class PopupMenu(gtk.Menu):
         
         self.show_all()
     
+    def _jump_next_to(self, caller, player):
+        player.jump_to = self.song
+        
     def _browse_artist(self, *args):
-        self._config["search-artist"] = str(self._song["artist"])
+        self._config["search-artist"] = str(self.song["artist"])
         self._config["search-album"] = "" 
         self._config["is-browser"] = True
         self._config.notify("is-browser")
@@ -44,8 +48,8 @@ class PopupMenu(gtk.Menu):
         self._config.notify("search-album")
 
     def _browse_album(self, *args):
-        self._config["search-artist"] = str(self._song["artist"])
-        self._config["search-album"] = str(self._song["album"])
+        self._config["search-artist"] = str(self.song["artist"])
+        self._config["search-album"] = str(self.song["album"])
         self._config["is-browser"] = True
         self._config.notify("is-browser")
         
@@ -54,5 +58,5 @@ class PopupMenu(gtk.Menu):
         self._config.notify("search-album")
  
     def _display_details(self, *args):        
-        self._details.set_data(self._song)
+        self._details.set_data(self.song)
         self._details.cshow()
\ No newline at end of file
