@@ -4,7 +4,7 @@ import hildon
 
 from youamp.ui.browser import Browser
 from youamp.ui.playlist import PlaylistView
-from youamp.ui import NOTHING_SELECTED, ARTIST_SELECTED, ALBUM_SELECTED
+from youamp.ui import ARTIST_SELECTED, ALBUM_SELECTED
 
 class BrowseButton(gtk.Button):
     def __init__(self):
@@ -86,10 +86,8 @@ class SearchView(gtk.VBox):
 
         self.pack_start(self._scroll)
 
-        self.show_all() 
+        self.show_all()
 
-        self.restore()
-   
         # browser callbacks
         self._config.notify_add("search-artist", self._on_artist_changed)
         self._config.notify_add("search-album", self._on_album_changed)
