@@ -6,7 +6,8 @@ import pango
 from youamp.ui.controls import Controls
 from youamp.ui.searchview import SearchView
 from youamp.ui.detailswindow import DetailsWindow
-from youamp import IS_MAEMO, img_path
+from youamp.ui.utils import CoverImage
+from youamp import IS_MAEMO
 
 class Menu(gtk.Menu):
     def __init__(self, config):
@@ -54,22 +55,6 @@ class Menu(gtk.Menu):
 
         self.show_all()
 
-class CoverImage(gtk.Image):
-    def __init__(self):
-        gtk.Image.__init__(self)
-        self.file = ""
-    
-    def set_generic(self):
-        name = "audio-x-generic" if not IS_MAEMO else "gnome-mime-audio-x-mp3"
-        pb = gtk.icon_theme_get_default().load_icon(name, self.size_request()[1], 0)
-        self.set_from_pixbuf(pb)
-        self.file = None
-    
-    def set_from_file(self, file):
-        pb = gtk.gdk.pixbuf_new_from_file_at_size(file, *self.size_request())
-        self.set_from_pixbuf(pb)
-        self.file = file
-
 class Window(hildon.Window):
     def __init__(self, player, config, library):
         hildon.Window.__init__(self)
@@ -163,15 +148,11 @@ class Window(hildon.Window):
         
         self._label.set_markup(label_txt)
         
-        # image
-        cover_file = newsong.cover_uri()
-        
-        if cover_file == self._cover.file:
+        # image        
+        if newsong["album"] == self._cover.album:
             return
-        elif cover_file is None:
-            self._cover.set_generic()
         else:
-            self._cover.set_from_file(cover_file)
+            self._cover.set_from_song(newsong)
             
         if not IS_MAEMO:
             self.set_icon_list(self._cover.get_pixbuf())
